@@ -4,9 +4,11 @@ use version; $VERSION = qv('0.0.7');
 
 use warnings;
 use strict;
+use Path::Class;
+use Data::Dumper;
 
 sub mk_compclass {
-    my ( $self, $helper, $schema) = @_;
+    my ( $self, $helper, $schema, $attrs) = @_;
     
     # controllers
     my @source_monikers = $schema->sources;
@@ -15,9 +17,45 @@ sub mk_compclass {
         (my $file = $helper->{file})  =~ s/InstantCRUD/$class/;
         $helper->{columns} = [ _getcolumns( $schema->source($class) ) ];
         $helper->{belongsto} = [ _getbelongsto( $schema->source($class) ) ];
+        $helper->{relations} = [ _getrelations( $schema->source($class), $attrs ) ];
         $helper->render_file( compclass => $file );
-        $helper->render_file( altcompclass => $file . '.alt' );
+#        $helper->render_file( altcompclass => $file );
+#        $helper->render_file( altcompclass => $file . '.alt' );
     }
+    my $interface_config_file = file( $helper->{dir}, 'interface_config.dat' );
+    my $interface_config = Dumper( $attrs->{config} );
+    $helper->mk_file( $interface_config_file, $interface_config);
+}
+
+sub _getrelations {
+    my ($table, $attrs) = @_;
+    my @columns;
+    my $inflector = DBIx::Class::Schema::Loader::RelBuilder->new;
+    my %mmrels;
+    for my $mmrel ( keys %{$attrs->{many_to_many_relation_table}} ){
+        $mmrels{$inflector->_inflect_plural($mmrel)} = $attrs->{many_to_many_relation_table}{$mmrel};
+    }
+    my $relatedclass;
+    for my $col ($table->relationships){
+        next if $table->has_column($col);
+        if( defined $mmrels{$col} ){
+            my @m2m = @{$mmrels{$col}};
+            if ($m2m[0] eq $table->name){
+                $col = $m2m[1];
+            }else{
+                $col = $m2m[2];
+            }
+            $relatedclass = ucfirst $col;  #horrible
+            $col = $inflector->_inflect_plural($col); #horror
+        }else{
+            my $info = $table->relationship_info( $col );
+            $relatedclass = $info->{class};
+        }
+
+        my $label = join ' ', map { ucfirst } split '_', $col;
+        push @columns, {widgettype => 'DoubleSelect', name => $col, label => $label, relatedclass => $relatedclass };
+    }
+    return @columns;
 }
 
 sub _getbelongsto {
@@ -68,11 +106,11 @@ sub _getcolumns {
             $widgettype = 'Password';
            push @constraints,  {
                 constraint => 'Equal',
-                args => [ "$col\_2" ],
+                args => "$col\_2",
                 message => "Passwords must match",
             }, {
                 constraint => 'AllOrNone',
-                args => [ "$col\_2" ],
+                args => "$col\_2", 
                 message => "Confirm the password",
             };
             push @columns, {widgettype => $widgettype, name => $col, label => $label, size => $size, constraints => \@constraints};
@@ -140,6 +178,24 @@ sub model_widget {
       $element->options(@options);
       $element->selected( $item->[% col.name %] ) if $id;
     [% END %]
+    [% FOR col = relations %]
+      $element = $w->element( '[% col.widgettype %]', '[% col.name %]' );
+      $element->label( '[% col.label%]' );
+      $element->multiple(1)->size(5);
+      @options = ( 0, '' );
+      $relatedclass = $model->resultset('[% col.relatedclass %]');
+      $ref_pk = ( $relatedclass->result_source->primary_columns ) [0];
+      for my $ref_item ( $relatedclass->search() ){
+          push @options, $ref_item->$ref_pk, "$ref_item"; 
+      }
+      $element->options(@options);
+      if ( $id ) {
+          my @selected = $item->[% col.name %]();
+          $element->selected(
+              [ @selected ? map( $_->$ref_pk, @selected ) : 0 ] );
+      } 
+      $element->selected( $item->[% col.name %] ) if $id;
+    [% END %]
     return HTML::Widget->new('widget')->method('post')->embed($w);
 }
 
